==> jc-1.4.0.tar.gz: polyglot/types/CachingResolver.h <==
// public class polyglot.types.CachingResolver

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c530a50397510e6f polyglot_types_CachingResolver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_CachingResolver_H_
#define _JC_polyglot_types_CachingResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Map$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_types_Named$object;
struct _jc_polyglot_types_Qualifier$object;
struct _jc_polyglot_types_Resolver$object;
struct _jc_polyglot_types_Type$object;

// Typedefs
typedef struct _jc_polyglot_types_CachingResolver$sub_refs	_jc_polyglot_types_CachingResolver$sub_refs;
typedef struct _jc_polyglot_types_CachingResolver$sub_nonrefs	_jc_polyglot_types_CachingResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_CachingResolver$refs	_jc_polyglot_types_CachingResolver$refs;
typedef struct _jc_polyglot_types_CachingResolver$nonrefs	_jc_polyglot_types_CachingResolver$nonrefs;
typedef struct _jc_polyglot_types_CachingResolver$object	_jc_polyglot_types_CachingResolver$object;

typedef struct _jc_polyglot_types_CachingResolver$fields_struct	_jc_polyglot_types_CachingResolver$fields_struct;
typedef const struct _jc_polyglot_types_CachingResolver$vmethods	_jc_polyglot_types_CachingResolver$vmethods;
typedef const struct _jc_polyglot_types_CachingResolver$vtable	_jc_polyglot_types_CachingResolver$vtable;
typedef const struct _jc_polyglot_types_CachingResolver$vtype	_jc_polyglot_types_CachingResolver$vtype;

// Class fields structure
struct _jc_polyglot_types_CachingResolver$fields_struct {
	struct _jc_object	*TOPICS;
};
extern _jc_polyglot_types_CachingResolver$fields_struct _jc_polyglot_types_CachingResolver$class_fields;

// Constructors
extern void _jc_polyglot_types_CachingResolver$method$_init$afc6b801f22f6106(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_CachingResolver$method$checkType$ebc7d9f2c168718e(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_polyglot_types_CachingResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_polyglot_types_CachingResolver$method$inner$26c33fbfd52948b6(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *);
extern void _jc_polyglot_types_CachingResolver$method$install$ccfcff1505013619(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_types_CachingResolver$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_CachingResolver$method_info$checkType$ebc7d9f2c168718e;
extern _jc_method _jc_polyglot_types_CachingResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_CachingResolver$method_info$inner$26c33fbfd52948b6;
extern _jc_method _jc_polyglot_types_CachingResolver$method_info$install$ccfcff1505013619;
extern _jc_method _jc_polyglot_types_CachingResolver$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_polyglot_types_CachingResolver$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_polyglot_types_CachingResolver$vmethods {
	struct _jc_object	*(*checkType$ebc7d9f2c168718e)(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*inner$26c33fbfd52948b6)(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *);
	void	(*install$ccfcff1505013619)(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *);
};

// Vtable
struct _jc_polyglot_types_CachingResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_CachingResolver$vmethods	polyglot_types_CachingResolver;
};

// Vtype
struct _jc_polyglot_types_CachingResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_CachingResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_CachingResolver$sub_refs {
	struct _jc_object	*inner;
	struct _jc_object	*cache;
	struct _jc_object	*extInfo;
};

// Reference instance fields (object)
struct _jc_polyglot_types_CachingResolver$refs {
    _jc_polyglot_types_CachingResolver$sub_refs	polyglot_types_CachingResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_CachingResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_CachingResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_CachingResolver$sub_nonrefs	polyglot_types_CachingResolver;
};

// Object instance structure
struct _jc_polyglot_types_CachingResolver$object {
	_jc_polyglot_types_CachingResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_CachingResolver$vtype	*vtype;
	_jc_polyglot_types_CachingResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_CachingResolver$vtype _jc_polyglot_types_CachingResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_CachingResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_CachingResolver$class_object;

#endif	/* _JC_polyglot_types_CachingResolver_H_ */

==> jc-1.4.6.tar.gz: polyglot/types/CachingResolver.h <==
// public class polyglot.types.CachingResolver

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c530a50397510e6f polyglot_types_CachingResolver

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_types_CachingResolver_H_
#define _JC_polyglot_types_CachingResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Map$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_types_Named$object;
struct _jc_polyglot_types_Qualifier$object;
struct _jc_polyglot_types_Resolver$object;
struct _jc_polyglot_types_Type$object;

// Typedefs
typedef struct _jc_polyglot_types_CachingResolver$sub_refs	_jc_polyglot_types_CachingResolver$sub_refs;
typedef struct _jc_polyglot_types_CachingResolver$sub_nonrefs	_jc_polyglot_types_CachingResolver$sub_nonrefs;
typedef struct _jc_polyglot_types_CachingResolver$refs	_jc_polyglot_types_CachingResolver$refs;
typedef struct _jc_polyglot_types_CachingResolver$nonrefs	_jc_polyglot_types_CachingResolver$nonrefs;
typedef struct _jc_polyglot_types_CachingResolver$object	_jc_polyglot_types_CachingResolver$object;

typedef struct _jc_polyglot_types_CachingResolver$fields_struct	_jc_polyglot_types_CachingResolver$fields_struct;
typedef const struct _jc_polyglot_types_CachingResolver$vmethods	_jc_polyglot_types_CachingResolver$vmethods;
typedef const struct _jc_polyglot_types_CachingResolver$vtable	_jc_polyglot_types_CachingResolver$vtable;
typedef const struct _jc_polyglot_types_CachingResolver$vtype	_jc_polyglot_types_CachingResolver$vtype;

// Class fields structure
struct _jc_polyglot_types_CachingResolver$fields_struct {
	struct _jc_object	*TOPICS;
};
extern _jc_polyglot_types_CachingResolver$fields_struct _jc_polyglot_types_CachingResolver$class_fields;

// Constructors
extern void _jc_polyglot_types_CachingResolver$method$_init$afc6b801f22f6106(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_polyglot_types_CachingResolver$method$checkType$ebc7d9f2c168718e(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_types_CachingResolver$method$find$6acc62ea1c707b3c(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_types_CachingResolver$method$inner$26c33fbfd52948b6(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_types_CachingResolver$method$install$ccfcff1505013619(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_types_CachingResolver$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_types_CachingResolver$method_info$checkType$ebc7d9f2c168718e;
extern _jc_method _jc_polyglot_types_CachingResolver$method_info$find$6acc62ea1c707b3c;
extern _jc_method _jc_polyglot_types_CachingResolver$method_info$inner$26c33fbfd52948b6;
extern _jc_method _jc_polyglot_types_CachingResolver$method_info$install$ccfcff1505013619;
extern _jc_method _jc_polyglot_types_CachingResolver$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_polyglot_types_CachingResolver$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_types_CachingResolver$vmethods {
	struct _jc_object	*(*checkType$ebc7d9f2c168718e)(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*find$6acc62ea1c707b3c)(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*inner$26c33fbfd52948b6)(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *) _JC_JCNI_ATTR;
	void	(*install$ccfcff1505013619)(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_types_CachingResolver$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_types_CachingResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_types_CachingResolver$vmethods	polyglot_types_CachingResolver;
};

// Vtype
struct _jc_polyglot_types_CachingResolver$vtype {
	_jc_type			type;
	_jc_polyglot_types_CachingResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_types_CachingResolver$sub_refs {
	struct _jc_object	*inner;
	struct _jc_object	*cache;
	struct _jc_object	*extInfo;
};

// Reference instance fields (object)
struct _jc_polyglot_types_CachingResolver$refs {
    _jc_polyglot_types_CachingResolver$sub_refs	polyglot_types_CachingResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_types_CachingResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_types_CachingResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_types_CachingResolver$sub_nonrefs	polyglot_types_CachingResolver;
};

// Object instance structure
struct _jc_polyglot_types_CachingResolver$object {
	_jc_polyglot_types_CachingResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_types_CachingResolver$vtype	*vtype;
	_jc_polyglot_types_CachingResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_types_CachingResolver$vtype _jc_polyglot_types_CachingResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_types_CachingResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_types_CachingResolver$class_object;

#endif	/* _JC_polyglot_types_CachingResolver_H_ */
